@@ -8,7 +8,6 @@ from flagai.data.tokenizer import GLM10bENBPETokenizer
 from flagai.data.tokenizer import T5BPETokenizer
 from flagai.data.tokenizer import ROBERTATokenizer
 from flagai.data.tokenizer import BertWordPieceTokenizer
-from flagai.data.tokenizer import CPMTokenizer
 from flagai.auto_model.auto_loader import AutoLoader
 
 class TokenizerTestCase(unittest.TestCase):
@@ -67,7 +66,8 @@ class TokenizerTestCase(unittest.TestCase):
     def test_tokenizer_cpm1(self):
         loader = AutoLoader(task_name="lm",
                             model_name="CPM-large-ch-generation",
-                            model_dir="./state_dict/")
+                            model_dir="./state_dict/",
+                            only_download_config=True)
         tokenizer = loader.get_tokenizer()
         self.assertEqual(tokenizer.encode("day"), [8, 8275], '')
         self.assertEqual(tokenizer.encode("fried chicken makes me happy"),
@@ -80,7 +80,7 @@ def suite():
     suite = unittest.TestSuite()
     suite.addTest(TokenizerTestCase('test_tokenizer_GLM_large_ch'))
     suite.addTest(TokenizerTestCase('test_tokenizer_GLM_large_en'))
-    suite.addTest(TokenizerTestCase('test_tokenizer_glm_10_en'))
+    #suite.addTest(TokenizerTestCase('test_tokenizer_glm_10_en'))
     suite.addTest(TokenizerTestCase('test_tokenizer_t5'))
     suite.addTest(TokenizerTestCase('test_tokenizer_roberta'))
     suite.addTest(TokenizerTestCase('test_tokenizer_bert'))
